##  Applying Filter
You can further apply various filters to drill down and get the information you need. To apply the filter you can use both the filter bar on top or filter facets on the left-hand side which becomes visible when you move the mouse pointer to the left side of the window.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a8ada7a441014905ff981084197b2_LowRes.png)
YesNo
Send
